<no title> — CALCEPH - Fortran 2003 language 3.4.1 documentation

    integer res
    real(8) jd0
    real(8) dt1
    real(8) P(3)
    TYPE(C_PTR) :: peph

    jd0 = 2442457
    dt1 = 0.5D0
    peph = calceph_open("example1.dat"//C_NULL_CHAR)
    if (C_ASSOCIATED(peph)) then

       res = calceph_orient_order(peph,jd0, dt1, NAIFID_MOON,
    &                            CALCEPH_USE_NAIFID+CALCEPH_UNIT_RAD+CALCEPH_UNIT_SEC,
    &                            0, P)
       write(*,*) P

        call calceph_close(peph)
     endif